# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchMode(str, Enum):
    """
    SearchMode
    """

    """
    allowed enum values
    """
    VECTOR = 'vector'
    BM25 = 'bm25'
    HYBRID = 'hybrid'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchMode from a JSON string"""
        return cls(json.loads(json_str))





# flake8: noqa

# import apis into api package
from yfkm3_services_search_client.api.documents_api import DocumentsApi
from yfkm3_services_search_client.api.evaluation_api import EvaluationApi
from yfkm3_services_search_client.api.indexes_api import IndexesApi
from yfkm3_services_search_client.api.langfuse_api import LangfuseApi
from yfkm3_services_search_client.api.search_api import SearchApi




# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.search_api import SearchApi


class TestSearchApi(unittest.IsolatedAsyncioTestCase):
    """SearchApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = SearchApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_health(self) -> None:
        """Test case for get_health

        健康检查
        """
        pass

    async def test_post_embeddings(self) -> None:
        """Test case for post_embeddings

        文本向量化接口
        """
        pass

    async def test_post_rerank(self) -> None:
        """Test case for post_rerank

        独立重排序接口
        """
        pass

    async def test_post_search(self) -> None:
        """Test case for post_search

        通用搜索接口
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from yfkm3_services_search_client.models.fusion_mode import FusionMode
from yfkm3_services_search_client.models.search_mode import SearchMode
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class SearchRequest(BaseModel):
    """
    SearchRequest
    """ # noqa: E501
    query: StrictStr
    space_id: StrictInt
    collection_ids: Optional[List[StrictInt]] = None
    mode: Optional[SearchMode] = None
    top_k: Optional[StrictInt] = 5
    candidate_top_k: Optional[StrictInt] = None
    vector_top_k: Optional[StrictInt] = None
    bm25_top_k: Optional[StrictInt] = None
    num_candidates: Optional[StrictInt] = None
    fusion_mode: Optional[FusionMode] = None
    rrf_k: Optional[StrictInt] = 60
    vector_weight: Optional[Union[StrictFloat, StrictInt]] = 0.5
    bm25_weight: Optional[Union[StrictFloat, StrictInt]] = 0.5
    document_type: Optional[StrictStr] = None
    document_id_list: Optional[List[StrictStr]] = None
    exclude_document_id_list: Optional[List[StrictStr]] = None
    exclude_paragraph_list: Optional[List[StrictStr]] = None
    query_vector: Optional[List[Union[StrictFloat, StrictInt]]] = None
    is_active: Optional[StrictBool] = None
    with_rerank: Optional[StrictBool] = False
    rerank_top_n: Optional[StrictInt] = None
    rerank_candidate_top_n: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["query", "space_id", "collection_ids", "mode", "top_k", "candidate_top_k", "vector_top_k", "bm25_top_k", "num_candidates", "fusion_mode", "rrf_k", "vector_weight", "bm25_weight", "document_type", "document_id_list", "exclude_document_id_list", "exclude_paragraph_list", "query_vector", "is_active", "with_rerank", "rerank_top_n", "rerank_candidate_top_n"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if candidate_top_k (nullable) is None
        # and model_fields_set contains the field
        if self.candidate_top_k is None and "candidate_top_k" in self.model_fields_set:
            _dict['candidate_top_k'] = None

        # set to None if vector_top_k (nullable) is None
        # and model_fields_set contains the field
        if self.vector_top_k is None and "vector_top_k" in self.model_fields_set:
            _dict['vector_top_k'] = None

        # set to None if bm25_top_k (nullable) is None
        # and model_fields_set contains the field
        if self.bm25_top_k is None and "bm25_top_k" in self.model_fields_set:
            _dict['bm25_top_k'] = None

        # set to None if num_candidates (nullable) is None
        # and model_fields_set contains the field
        if self.num_candidates is None and "num_candidates" in self.model_fields_set:
            _dict['num_candidates'] = None

        # set to None if document_type (nullable) is None
        # and model_fields_set contains the field
        if self.document_type is None and "document_type" in self.model_fields_set:
            _dict['document_type'] = None

        # set to None if document_id_list (nullable) is None
        # and model_fields_set contains the field
        if self.document_id_list is None and "document_id_list" in self.model_fields_set:
            _dict['document_id_list'] = None

        # set to None if exclude_document_id_list (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_document_id_list is None and "exclude_document_id_list" in self.model_fields_set:
            _dict['exclude_document_id_list'] = None

        # set to None if exclude_paragraph_list (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_paragraph_list is None and "exclude_paragraph_list" in self.model_fields_set:
            _dict['exclude_paragraph_list'] = None

        # set to None if query_vector (nullable) is None
        # and model_fields_set contains the field
        if self.query_vector is None and "query_vector" in self.model_fields_set:
            _dict['query_vector'] = None

        # set to None if is_active (nullable) is None
        # and model_fields_set contains the field
        if self.is_active is None and "is_active" in self.model_fields_set:
            _dict['is_active'] = None

        # set to None if rerank_top_n (nullable) is None
        # and model_fields_set contains the field
        if self.rerank_top_n is None and "rerank_top_n" in self.model_fields_set:
            _dict['rerank_top_n'] = None

        # set to None if rerank_candidate_top_n (nullable) is None
        # and model_fields_set contains the field
        if self.rerank_candidate_top_n is None and "rerank_candidate_top_n" in self.model_fields_set:
            _dict['rerank_candidate_top_n'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "query": obj.get("query"),
            "space_id": obj.get("space_id"),
            "collection_ids": obj.get("collection_ids"),
            "mode": obj.get("mode"),
            "top_k": obj.get("top_k") if obj.get("top_k") is not None else 5,
            "candidate_top_k": obj.get("candidate_top_k"),
            "vector_top_k": obj.get("vector_top_k"),
            "bm25_top_k": obj.get("bm25_top_k"),
            "num_candidates": obj.get("num_candidates"),
            "fusion_mode": obj.get("fusion_mode"),
            "rrf_k": obj.get("rrf_k") if obj.get("rrf_k") is not None else 60,
            "vector_weight": obj.get("vector_weight") if obj.get("vector_weight") is not None else 0.5,
            "bm25_weight": obj.get("bm25_weight") if obj.get("bm25_weight") is not None else 0.5,
            "document_type": obj.get("document_type"),
            "document_id_list": obj.get("document_id_list"),
            "exclude_document_id_list": obj.get("exclude_document_id_list"),
            "exclude_paragraph_list": obj.get("exclude_paragraph_list"),
            "query_vector": obj.get("query_vector"),
            "is_active": obj.get("is_active"),
            "with_rerank": obj.get("with_rerank") if obj.get("with_rerank") is not None else False,
            "rerank_top_n": obj.get("rerank_top_n"),
            "rerank_candidate_top_n": obj.get("rerank_candidate_top_n")
        })
        return _obj





# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.langfuse_api import LangfuseApi


class TestLangfuseApi(unittest.IsolatedAsyncioTestCase):
    """LangfuseApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = LangfuseApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_langfuse_datasets(self) -> None:
        """Test case for get_langfuse_datasets

        获取 Langfuse 数据集与样本
        """
        pass

    async def test_post_langfuse_datasets_auto_annotate(self) -> None:
        """Test case for post_langfuse_datasets_auto_annotate

        LLM 自动标注 Langfuse 数据集
        """
        pass

    async def test_post_langfuse_datasets_evaluate_only(self) -> None:
        """Test case for post_langfuse_datasets_evaluate_only

        仅评测 Langfuse 数据集（跳过搜索步骤）
        """
        pass

    async def test_post_langfuse_datasets_evaluate_sync(self) -> None:
        """Test case for post_langfuse_datasets_evaluate_sync

        同步执行 Langfuse 数据集评测
        """
        pass

    async def test_post_langfuse_datasets_items(self) -> None:
        """Test case for post_langfuse_datasets_items

        新增 Langfuse 数据集样本
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.rerank_request import RerankRequest

class TestRerankRequest(unittest.TestCase):
    """RerankRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RerankRequest:
        """Test RerankRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RerankRequest`
        """
        model = RerankRequest()
        if include_optional:
            return RerankRequest(
                query = '',
                documents = [
                    { }
                    ],
                top_n = 56
            )
        else:
            return RerankRequest(
                query = '',
                documents = [
                    { }
                    ],
        )
        """

    def testRerankRequest(self):
        """Test RerankRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.bulk_response import BulkResponse

class TestBulkResponse(unittest.TestCase):
    """BulkResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkResponse:
        """Test BulkResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkResponse`
        """
        model = BulkResponse()
        if include_optional:
            return BulkResponse(
                status = '',
                total = 56,
                success_count = 56,
                fail_count = 56,
                results = [
                    yfkm3_services_search_client.models.bulk_operation_result.BulkOperationResult(
                        id = '', 
                        action = '', 
                        success = True, 
                        error = '', )
                    ]
            )
        else:
            return BulkResponse(
                status = '',
                total = 56,
                success_count = 56,
                fail_count = 56,
        )
        """

    def testBulkResponse(self):
        """Test BulkResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.embeddings_response import EmbeddingsResponse

class TestEmbeddingsResponse(unittest.TestCase):
    """EmbeddingsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EmbeddingsResponse:
        """Test EmbeddingsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EmbeddingsResponse`
        """
        model = EmbeddingsResponse()
        if include_optional:
            return EmbeddingsResponse(
                embeddings = [
                    [
                        1.337
                        ]
                    ]
            )
        else:
            return EmbeddingsResponse(
                embeddings = [
                    [
                        1.337
                        ]
                    ],
        )
        """

    def testEmbeddingsResponse(self):
        """Test EmbeddingsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.3"

# Define package exports
__all__ = [
    "DocumentsApi",
    "EvaluationApi",
    "IndexesApi",
    "LangfuseApi",
    "SearchApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ActionResponse",
    "AutoAnnotateRequest",
    "AutoAnnotateResponse",
    "BulkOperation",
    "BulkOperationResult",
    "BulkResponse",
    "ChunkResponse",
    "ChunksByDocumentIdRequest",
    "ChunksListResponse",
    "CountResponse",
    "DatasetSyncEvalRequest",
    "DatasetSyncEvalResponse",
    "DocsAddRequest",
    "DocsBulkRequest",
    "DocsDeleteRequest",
    "DocsUpdateRequest",
    "DocumentIn",
    "EmbeddingsRequest",
    "EmbeddingsResponse",
    "EvaluateRequest",
    "EvaluateResponse",
    "FusionMode",
    "HTTPValidationError",
    "HealthResponse",
    "IndexCreateRequest",
    "IndexStatusResponse",
    "LangfuseActionResponse",
    "LangfuseDatasetItemRequest",
    "LangfuseDatasetResponse",
    "LangfuseEvalOnlyRequest",
    "LocationInner",
    "RerankRequest",
    "RerankResponse",
    "SearchMode",
    "SearchRequest",
    "SearchResponse",
    "SearchResultItem",
    "ValidationError",
]

# import apis into sdk package
from yfkm3_services_search_client.api.documents_api import DocumentsApi as DocumentsApi
from yfkm3_services_search_client.api.evaluation_api import EvaluationApi as EvaluationApi
from yfkm3_services_search_client.api.indexes_api import IndexesApi as IndexesApi
from yfkm3_services_search_client.api.langfuse_api import LangfuseApi as LangfuseApi
from yfkm3_services_search_client.api.search_api import SearchApi as SearchApi

# import ApiClient
from yfkm3_services_search_client.api_response import ApiResponse as ApiResponse
from yfkm3_services_search_client.api_client import ApiClient as ApiClient
from yfkm3_services_search_client.configuration import Configuration as Configuration
from yfkm3_services_search_client.exceptions import OpenApiException as OpenApiException
from yfkm3_services_search_client.exceptions import ApiTypeError as ApiTypeError
from yfkm3_services_search_client.exceptions import ApiValueError as ApiValueError
from yfkm3_services_search_client.exceptions import ApiKeyError as ApiKeyError
from yfkm3_services_search_client.exceptions import ApiAttributeError as ApiAttributeError
from yfkm3_services_search_client.exceptions import ApiException as ApiException

# import models into sdk package
from yfkm3_services_search_client.models.action_response import ActionResponse as ActionResponse
from yfkm3_services_search_client.models.auto_annotate_request import AutoAnnotateRequest as AutoAnnotateRequest
from yfkm3_services_search_client.models.auto_annotate_response import AutoAnnotateResponse as AutoAnnotateResponse
from yfkm3_services_search_client.models.bulk_operation import BulkOperation as BulkOperation
from yfkm3_services_search_client.models.bulk_operation_result import BulkOperationResult as BulkOperationResult
from yfkm3_services_search_client.models.bulk_response import BulkResponse as BulkResponse
from yfkm3_services_search_client.models.chunk_response import ChunkResponse as ChunkResponse
from yfkm3_services_search_client.models.chunks_by_document_id_request import ChunksByDocumentIdRequest as ChunksByDocumentIdRequest
from yfkm3_services_search_client.models.chunks_list_response import ChunksListResponse as ChunksListResponse
from yfkm3_services_search_client.models.count_response import CountResponse as CountResponse
from yfkm3_services_search_client.models.dataset_sync_eval_request import DatasetSyncEvalRequest as DatasetSyncEvalRequest
from yfkm3_services_search_client.models.dataset_sync_eval_response import DatasetSyncEvalResponse as DatasetSyncEvalResponse
from yfkm3_services_search_client.models.docs_add_request import DocsAddRequest as DocsAddRequest
from yfkm3_services_search_client.models.docs_bulk_request import DocsBulkRequest as DocsBulkRequest
from yfkm3_services_search_client.models.docs_delete_request import DocsDeleteRequest as DocsDeleteRequest
from yfkm3_services_search_client.models.docs_update_request import DocsUpdateRequest as DocsUpdateRequest
from yfkm3_services_search_client.models.document_in import DocumentIn as DocumentIn
from yfkm3_services_search_client.models.embeddings_request import EmbeddingsRequest as EmbeddingsRequest
from yfkm3_services_search_client.models.embeddings_response import EmbeddingsResponse as EmbeddingsResponse
from yfkm3_services_search_client.models.evaluate_request import EvaluateRequest as EvaluateRequest
from yfkm3_services_search_client.models.evaluate_response import EvaluateResponse as EvaluateResponse
from yfkm3_services_search_client.models.fusion_mode import FusionMode as FusionMode
from yfkm3_services_search_client.models.http_validation_error import HTTPValidationError as HTTPValidationError
from yfkm3_services_search_client.models.health_response import HealthResponse as HealthResponse
from yfkm3_services_search_client.models.index_create_request import IndexCreateRequest as IndexCreateRequest
from yfkm3_services_search_client.models.index_status_response import IndexStatusResponse as IndexStatusResponse
from yfkm3_services_search_client.models.langfuse_action_response import LangfuseActionResponse as LangfuseActionResponse
from yfkm3_services_search_client.models.langfuse_dataset_item_request import LangfuseDatasetItemRequest as LangfuseDatasetItemRequest
from yfkm3_services_search_client.models.langfuse_dataset_response import LangfuseDatasetResponse as LangfuseDatasetResponse
from yfkm3_services_search_client.models.langfuse_eval_only_request import LangfuseEvalOnlyRequest as LangfuseEvalOnlyRequest
from yfkm3_services_search_client.models.location_inner import LocationInner as LocationInner
from yfkm3_services_search_client.models.rerank_request import RerankRequest as RerankRequest
from yfkm3_services_search_client.models.rerank_response import RerankResponse as RerankResponse
from yfkm3_services_search_client.models.search_mode import SearchMode as SearchMode
from yfkm3_services_search_client.models.search_request import SearchRequest as SearchRequest
from yfkm3_services_search_client.models.search_response import SearchResponse as SearchResponse
from yfkm3_services_search_client.models.search_result_item import SearchResultItem as SearchResultItem
from yfkm3_services_search_client.models.validation_error import ValidationError as ValidationError




# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.documents_api import DocumentsApi


class TestDocumentsApi(unittest.IsolatedAsyncioTestCase):
    """DocumentsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DocumentsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_docs_chunks(self) -> None:
        """Test case for get_docs_chunks

        通过 chunk_id 获取单个 chunk
        """
        pass

    async def test_post_docs_add(self) -> None:
        """Test case for post_docs_add

        批量添加文档
        """
        pass

    async def test_post_docs_bulk(self) -> None:
        """Test case for post_docs_bulk

        批量操作文档（create/update/delete）
        """
        pass

    async def test_post_docs_chunks(self) -> None:
        """Test case for post_docs_chunks

        通过 document_id 获取所有 chunk
        """
        pass

    async def test_post_docs_delete(self) -> None:
        """Test case for post_docs_delete

        批量删除文档
        """
        pass

    async def test_post_docs_update(self) -> None:
        """Test case for post_docs_update

        批量更新文档元数据
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.search_request import SearchRequest

class TestSearchRequest(unittest.TestCase):
    """SearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchRequest:
        """Test SearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchRequest`
        """
        model = SearchRequest()
        if include_optional:
            return SearchRequest(
                query = '',
                space_id = 56,
                collection_ids = [
                    56
                    ],
                mode = 'vector',
                top_k = 56,
                candidate_top_k = 56,
                vector_top_k = 56,
                bm25_top_k = 56,
                num_candidates = 56,
                fusion_mode = 'rrf',
                rrf_k = 56,
                vector_weight = 1.337,
                bm25_weight = 1.337,
                document_type = '',
                document_id_list = [
                    ''
                    ],
                exclude_document_id_list = [
                    ''
                    ],
                exclude_paragraph_list = [
                    ''
                    ],
                query_vector = [
                    1.337
                    ],
                is_active = True,
                with_rerank = True,
                rerank_top_n = 56,
                rerank_candidate_top_n = 56
            )
        else:
            return SearchRequest(
                query = '',
                space_id = 56,
        )
        """

    def testSearchRequest(self):
        """Test SearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.docs_add_request import DocsAddRequest

class TestDocsAddRequest(unittest.TestCase):
    """DocsAddRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocsAddRequest:
        """Test DocsAddRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocsAddRequest`
        """
        model = DocsAddRequest()
        if include_optional:
            return DocsAddRequest(
                space_id = 56,
                collection_id = 56,
                documents = [
                    yfkm3_services_search_client.models.document_in.DocumentIn(
                        content = '', 
                        embedding = [
                            1.337
                            ], 
                        document_id = '', 
                        metadata = { }, )
                    ]
            )
        else:
            return DocsAddRequest(
                space_id = 56,
                collection_id = 56,
        )
        """

    def testDocsAddRequest(self):
        """Test DocsAddRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from yfkm3_services_search_client.models.action_response import ActionResponse
from yfkm3_services_search_client.models.auto_annotate_request import AutoAnnotateRequest
from yfkm3_services_search_client.models.auto_annotate_response import AutoAnnotateResponse
from yfkm3_services_search_client.models.bulk_operation import BulkOperation
from yfkm3_services_search_client.models.bulk_operation_result import BulkOperationResult
from yfkm3_services_search_client.models.bulk_response import BulkResponse
from yfkm3_services_search_client.models.chunk_response import ChunkResponse
from yfkm3_services_search_client.models.chunks_by_document_id_request import ChunksByDocumentIdRequest
from yfkm3_services_search_client.models.chunks_list_response import ChunksListResponse
from yfkm3_services_search_client.models.count_response import CountResponse
from yfkm3_services_search_client.models.dataset_sync_eval_request import DatasetSyncEvalRequest
from yfkm3_services_search_client.models.dataset_sync_eval_response import DatasetSyncEvalResponse
from yfkm3_services_search_client.models.docs_add_request import DocsAddRequest
from yfkm3_services_search_client.models.docs_bulk_request import DocsBulkRequest
from yfkm3_services_search_client.models.docs_delete_request import DocsDeleteRequest
from yfkm3_services_search_client.models.docs_update_request import DocsUpdateRequest
from yfkm3_services_search_client.models.document_in import DocumentIn
from yfkm3_services_search_client.models.embeddings_request import EmbeddingsRequest
from yfkm3_services_search_client.models.embeddings_response import EmbeddingsResponse
from yfkm3_services_search_client.models.evaluate_request import EvaluateRequest
from yfkm3_services_search_client.models.evaluate_response import EvaluateResponse
from yfkm3_services_search_client.models.fusion_mode import FusionMode
from yfkm3_services_search_client.models.http_validation_error import HTTPValidationError
from yfkm3_services_search_client.models.health_response import HealthResponse
from yfkm3_services_search_client.models.index_create_request import IndexCreateRequest
from yfkm3_services_search_client.models.index_status_response import IndexStatusResponse
from yfkm3_services_search_client.models.langfuse_action_response import LangfuseActionResponse
from yfkm3_services_search_client.models.langfuse_dataset_item_request import LangfuseDatasetItemRequest
from yfkm3_services_search_client.models.langfuse_dataset_response import LangfuseDatasetResponse
from yfkm3_services_search_client.models.langfuse_eval_only_request import LangfuseEvalOnlyRequest
from yfkm3_services_search_client.models.location_inner import LocationInner
from yfkm3_services_search_client.models.rerank_request import RerankRequest
from yfkm3_services_search_client.models.rerank_response import RerankResponse
from yfkm3_services_search_client.models.search_mode import SearchMode
from yfkm3_services_search_client.models.search_request import SearchRequest
from yfkm3_services_search_client.models.search_response import SearchResponse
from yfkm3_services_search_client.models.search_result_item import SearchResultItem
from yfkm3_services_search_client.models.validation_error import ValidationError




# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.search_mode import SearchMode

class TestSearchMode(unittest.TestCase):
    """SearchMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchMode(self):
        """Test SearchMode"""
        # inst = SearchMode()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.indexes_api import IndexesApi


class TestIndexesApi(unittest.IsolatedAsyncioTestCase):
    """IndexesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = IndexesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_index_exists(self) -> None:
        """Test case for get_index_exists

        检查统一索引是否存在
        """
        pass

    async def test_post_index_create(self) -> None:
        """Test case for post_index_create

        创建统一搜索索引
        """
        pass


if __name__ == '__main__':
    unittest.main()
